@@ -22,7 +22,6 @@
 #include "mark.h"
 
 #include <QTimer>
-#include <QColor>
 #include <QPainter>
 #include <QSvgRenderer>
 
@@ -38,7 +37,7 @@ namespace gui {
 Mark::Mark(Scene* scene, const Move& move, bool animate, qreal fill) : QGraphicsSvgItem(),
   m_scene(scene), m_row(move.y()), m_col(move.x()), m_fill(fill) {
     m_sizeShrink = 1.0/12.0; //1.0/(qrand()%5+7.0);
-    setElementId(QString(move.player() == X ? QLatin1String("x%1") : QLatin1String("o%1"))
+    setElementId(QString(move.player() == X ? QStringLiteral("x%1") : QStringLiteral("o%1"))
             .arg(QString::number(qrand() % 5 + 1)));
     m_tick = 20;
     m_ticker = 0;
